@@ -1,5 +1,5 @@
 import gy_multiprocessing.multiprocessing
-import gy_multiprocessing.multipool
+import gy_multiprocessing.multithreading
 
 
 def hello_world() -> None:
